@@ -59,7 +59,6 @@ def parse(html: str, p: Product, include: Sequence = None):
         return "variation_values" in include or "selected_variations" in include or "asin_variation_values" in include
 
     sel = parsel.Selector(text=html)
-    "product_asin" in include and parse_product_asin(p, selector=sel)
     "parent_asin" in include and parse_parent_asin(p, selector=sel)
     "weight" in include and parse_weight(p, selector=sel)
     "brand" in include and parse_brand(p, selector=sel)
@@ -83,10 +82,6 @@ def parse(html: str, p: Product, include: Sequence = None):
     "rank" in include and parse_rank(p, selector=sel)
 
 
-def parse_product_asin(p: Product, selector: parsel.Selector = None):
-    p.product_asin = selector.re_first(r'"landingAsin":"(.+?)"')
-
-
 def parse_parent_asin(p: Product, selector: parsel.Selector = None):
     p.parent_asin = selector.re_first(r'"parentAsin":"(.+?)"')
 
